@@ -135,7 +135,9 @@ class HpIlo(object):
                 if status != BlobReturnCodes.SUCCESS:
                     errmsg = "Error {0} occurred while trying to open a " "channel to iLO".format(status)
                     if status == BlobReturnCodes.CHIFERR_NoDriver:
-                        errmsg = "chif"
+                        errmsg = "No devices were found."
+                        if os.name != "nt":
+                            errmsg = "{0} Ensure the hpilo kernel module is loaded.".format(errmsg)
                     elif status == BlobReturnCodes.CHIFERR_AccessDenied:
                         errmsg = "You must be root/Administrator to use this program."
                     raise HpIloInitialError(errmsg)
